==> git-open-1.0.3.tar.gz: git-open-1.0.3/CONTRIBUTING.md <==
Contributing
============

Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.

You can contribute in many ways:

Types of Contributions
----------------------

### Report Bugs

Report bugs at [https://github.com/cfp2000/git-open/issues].

If you are reporting a bug, please include:

* Your operating system name and version.
* Any details about your local setup that might be helpful in troubleshooting.
* Detailed steps to reproduce the bug.

### Fix Bugs


Look through the https://github.com/cfp2000/git-open/issues for bugs. Anything tagged with "bug"
and "help wanted" is open to whoever wants to implement it.

### Implement Features

Look through the https://github.com/cfp2000/git-open/issues for features. Anything tagged with "enhancement"
and "help wanted" is open to whoever wants to implement it.

### Write Documentation


git open could always use more documentation, whether as part of the
official git open docs, in docstrings, or even on the web in blog posts,
articles, and such.

### Submit Feedback


The best way to send feedback is to file an issue at [https://github.com/cfp2000/git-open/issues].

If you are proposing a feature:

* Explain in detail how it would work.
* Keep the scope as narrow as possible, to make it easier to implement.
* Remember that this is a volunteer-driven project, and that contributions
  are welcome :)

Get Started!
------------

Ready to contribute? Here's how to set up `git_open` for local development.

1. Fork the `git_open` repo on [https://github.com/cfp2000/git-open].
2. Clone your fork locally::

    $ git clone git@github.com:your_name_here/git_open.git

3. Install your local copy into a virtualenv. Assuming you have virtualenvwrapper installed, this is how you set up your fork for local development::

    $ mkvirtualenv git_open
    $ cd git_open/
    $ python setup.py develop

4. Create a branch for local development::

    $ git checkout -b name-of-your-bugfix-or-feature

   Now you can make your changes locally.

5. When you're done making changes, check that your changes pass flake8 and the tests, including testing other Python versions with tox::

    $ flake8 git_open tests
    $ python setup.py test or py.test
    $ tox

   To get flake8 and tox, just pip install them into your virtualenv.

6. Commit your changes and push your branch to github

    $ git add .
    $ git commit -m "Your detailed description of your changes."
    $ git push origin name-of-your-bugfix-or-feature

7. Submit a pull request through the website.

Pull Request Guidelines
-----------------------

Update...

Tips
----

To run a subset of tests:

    $ py.test tests.test_git_open

==> git-open-1.1.2.tar.gz: git-open-1.1.2/CONTRIBUTING.md <==
Contributing
============

Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.

You can contribute in many ways:

Types of Contributions
----------------------

### Report Bugs

Report bugs at [https://github.com/cfarvidson/git-open/issues].

If you are reporting a bug, please include:

* Your operating system name and version.
* Any details about your local setup that might be helpful in troubleshooting.
* Detailed steps to reproduce the bug.

### Fix Bugs


Look through the https://github.com/cfarvidson/git-open/issues for bugs. Anything tagged with "bug"
and "help wanted" is open to whoever wants to implement it.

### Implement Features

Look through the https://github.com/cfarvidson/git-open/issues for features. Anything tagged with "enhancement"
and "help wanted" is open to whoever wants to implement it.

### Write Documentation


git open could always use more documentation, whether as part of the
official git open docs, in docstrings, or even on the web in blog posts,
articles, and such.

### Submit Feedback


The best way to send feedback is to file an issue at [https://github.com/cfarvidson/git-open/issues].

If you are proposing a feature:

* Explain in detail how it would work.
* Keep the scope as narrow as possible, to make it easier to implement.
* Remember that this is a volunteer-driven project, and that contributions
  are welcome :)

Get Started!
------------

Ready to contribute? Here's how to set up `git_open` for local development.

1. Fork the `git_open` repo on [https://github.com/cfarvidson/git-open].
2. Clone your fork locally::

    $ git clone git@github.com:your_name_here/git_open.git

3. Install your local copy into a virtualenv. Assuming you have virtualenvwrapper installed, this is how you set up your fork for local development::

    $ mkvirtualenv git_open
    $ cd git_open/
    $ python setup.py develop

4. Create a branch for local development::

    $ git checkout -b name-of-your-bugfix-or-feature

   Now you can make your changes locally.

5. When you're done making changes, check that your changes pass flake8 and the tests, including testing other Python versions with tox::

    $ flake8 git_open tests
    $ python setup.py test or py.test
    $ tox

   To get flake8 and tox, just pip install them into your virtualenv.

6. Commit your changes and push your branch to github

    $ git add .
    $ git commit -m "Your detailed description of your changes."
    $ git push origin name-of-your-bugfix-or-feature

7. Submit a pull request through the website.

Pull Request Guidelines
-----------------------

Update...

Tips
----

To run a subset of tests:

    $ py.test tests.test_git_open
